
import { UserAvatar } from "@/components/user-avatar";
import { db } from "@/lib/db";
import { User } from "@prisma/client";
import { getServerSession } from "next-auth";

export default async function UserFollowers({ params }: { params: { userid: string } }) {
    // const session = await getServerSession(authOptions);

    // if (!session) {
    //     return <div>Loading...</div>;
    // }

    const fullUser = await db.user.findFirst({
        where: {
            username: params.userid
        },
        include: {
            following: true,
            followers: true
        }
    })


    const followers = await db.user.findMany({
        where: {
            following: {
                every: {
                    followerId: { not: undefined }
                }
            },
            followers: {
                every: {
                    followingId: fullUser?.id
                }
            }
        }
    })

    return (
        <div>
            <h1>Followers Page WIP</h1>
            {followers?.map((follower: User) => (
                <div key={follower.id}> {follower.id} <UserAvatar
                    user={{ username: follower.name || null, image: follower.image || null }}
                    className="h-20 w-20 -mt-50" />

                    <div className="ml-6 md:ml-12 space-y-3">
                        <h1 className="text-2xl font-bold">{follower.name}</h1>
                        <h1 className="text-md text-sky-500">@{follower.username}</h1>
                    </div>
                </div>
            ))}
        </div>
    )
}


